@@ -81,11 +81,11 @@ class Central_widget(QtGui.QWidget):
                                     QtCore.Qt.WA_Maemo5ShowProgressIndicator,
                                     True)
         self.parent.main_window.repaint()
-        banner_notification("Loading Bonjour contacts ...")
+        banner_notification("Looking for Bonjour contacts ...")
         self.parent.bonjour_users = list_presence_users()
         self.bonjour_users.clear()
         if len(self.parent.bonjour_users) == 0:
-            banner_notification("NO Bonjour contacts found !")
+            banner_notification("No Bonjour contacts found !")
         else:
             for bonjour_user, info in self.parent.bonjour_users.items():
                 self.bonjour_users.addItem(bonjour_user)
